# _*_ coding: utf-8 _*_
#
# HSPyLib v0.10.9
#
# Package: main.hspylib.modules.cli.icons.font_awesome
"""Package initialization."""

__all__ = [
  'awesome', 
  'dashboard_icons', 
  'form_icons', 
  'widget_icons'
]
